<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}
class Zuzu_Recent_Posts_Widget extends WP_Widget
{
  /**
   * To create the example widget all four methods will be
   * nested inside this single instance of the WP_Widget class.
   **/

  public function __construct()
  {
    $widget_options = array(
      'classname' => 'zuzu_recent_posts_Widget',
      'description' => 'This widget will show latest post with thumbnail.',
    );
    parent::__construct('zuzu_recent_posts_Widget', 'Zuzu Recent Posts', $widget_options);
  }


  public function widget($args, $instance)
  {
    $title = apply_filters('widget_title', $instance['title']);
    $show_post_date = apply_filters('widget_show_post_date', $instance['show_post_date']);
    $ppp = (!empty($instance['ppp']) ? $instance['ppp'] : -1);

    echo $args['before_widget'] . $args['before_title'] . esc_html($title) . $args['after_title'];

    $query_args = array(
      'post_type' => 'post',
      'posts_per_page' => $ppp,
    );

    $query = new WP_Query($query_args);

    if ($query->have_posts()) {

      while ($query->have_posts()) {
        $query->the_post(); ?>

        <div class="post-item clearfix">
          <div class="post-thumb">
            <?php
            $thumb_id = get_post_thumbnail_id(get_the_ID());
            $img = wp_get_attachment_image_src($thumb_id, 'zuzu-blog-widget-thumb');

            if (has_post_thumbnail()) :
              printf('<a href="%s"><img src="%s" alt="%s" /></a>', get_the_permalink(), $img[0], esc_attr(get_the_title()));

		
            else :
              printf('<a href="%s"><img src="%s" class="rounded-default" alt="%s" /></a>', get_the_permalink(), '//via.placeholder.com/70x70.png', esc_attr(get_the_title()));

            endif;
            ?>
          </div>
          <p class="post-text">

		  	<?php if ($show_post_date) : ?>

              <span class="post-date">
                <svg width="20" height="20" viewBox="0 0 20 20" fill="none" xmlns="http://www.w3.org/2000/svg">
                  <path d="M6.66667 5.83333V2.5M13.3333 5.83333V2.5M5.83333 9.16667H14.1667M4.16667 17.5H15.8333C16.7538 17.5 17.5 16.7538 17.5 15.8333V5.83333C17.5 4.91286 16.7538 4.16667 15.8333 4.16667H4.16667C3.24619 4.16667 2.5 4.91286 2.5 5.83333V15.8333C2.5 16.7538 3.24619 17.5 4.16667 17.5Z" stroke="#13111A" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"/>
                </svg>

                <?php echo get_the_date(); ?>
              </span>
            <?php endif; ?>

            <a class="post-title" href="<?php the_permalink(); ?>">
				<?php echo get_the_title(); ?>
			</a>
          </p>
        </div>

    <?php

      }
      wp_reset_postdata();
    }

    echo $args['after_widget'];
  }

  public function form($instance)
  {
    $title = !empty($instance['title']) ? $instance['title'] : '';
    $show_post_date = !empty($instance['show_post_date']) ? $instance['show_post_date'] : '';
    $ppp = !empty($instance['$ppp']) ? $instance['$ppp'] : 5;

    ?>
    <p>
      <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title:', 'zuzu'); ?></label>
      <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" value="<?php echo esc_attr($title); ?>" />
    </p>

    <p>
      <label for="<?php echo esc_attr($this->get_field_id('show_post_date')); ?>"><?php esc_html_e('Display Post Date?', 'zuzu'); ?></label>
      <input type="checkbox" id="<?php echo esc_attr($this->get_field_id('show_post_date')) ?>" name="<?php echo esc_attr($this->get_field_name('show_post_date')) ?>" <?php if ($show_post_date == 'on') { echo ' checked'; } ?>>
    </p>

    <p>
      <label for="<?php echo esc_attr($this->get_field_id('ppp')); ?>"><?php esc_html_e('Post per page:', 'zuzu'); ?></label>
      <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('ppp')); ?>" name="<?php echo esc_attr($this->get_field_name('ppp')); ?>" value="<?php echo esc_attr($ppp); ?>" />
    </p>

<?php
  }
  public function update($new_instance, $old_instance)
  {
    $instance = $old_instance;
    $instance['title'] = strip_tags($new_instance['title']);
    $instance['ppp'] = strip_tags($new_instance['ppp']);
    $instance['show_post_date'] = strip_tags($new_instance['show_post_date']);
    return $instance;
  }
}





function zuzu_plugin_widget_reg()
{
  register_widget('Zuzu_Recent_Posts_Widget');
}
add_action('widgets_init', 'zuzu_plugin_widget_reg');

?>