<?php
if (!defined('ABSPATH')) {
    exit;
}
// Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Zuzu_Portfolio_Gallery extends \Elementor\Widget_Base
{
    /**
     * Retrieve the widget name.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'zuzu-portfolio-gallery';
    }

    public function get_script_depends()
    {
        return ['isotope', 'zuzu-addon'];
    }
    /**
     * Retrieve the widget title.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return __('Zuzu Portfolio Gallery', 'zuzu-hp');
    }
    /**
     * Retrieve the widget icon.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-gallery-grid';
    }
    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['zuzu-addons'];
    }
    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function register_controls()
    {
        $this->start_controls_section(
            'section_gallery',
            [
                'label' => __('Gallery', 'zuzu-hp'),
            ]
        );
        

        $this->add_control(
            'layout_type',
            [
                'label' => __('Layout type', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => array(
                    'masonry' => 'Masonry',
                    'normal' => 'Normal',
                    'slider' => 'Slider'
                ),
                'default' => 'masonry',
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
			'image',
			[
				'label' => __( 'Choose Image', 'zuzu-hp' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
        );
        
        $repeater->add_control(
			'image_size',
			[
				'label' => __( 'Image Dimension', 'zuzu-hp' ),
				'type' => \Elementor\Controls_Manager::IMAGE_DIMENSIONS,
				'description' => __( 'Crop the original image size to any custom size. Set custom width or height to keep the original size ratio.', 'zuzu-hp' ),
				'default' => [
					'width' => '',
					'height' => '',
				],
			]
        );
        $repeater->add_responsive_control(
            'image_grid',
            [
                'label' => __('Image grid', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => array(
                    '' => 'Default',
                    '12' => '1 Column',
                    '6' => '2 Column',
                    '4' => '3 Column',
                    '3' => '4 Column',
                ),
                'default'            => '',
            ]
        );
        
        $repeater->add_control(
			'image_title',
			[
				'label' => __( 'Title', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'placeholder' => __( 'Type your title here', 'plugin-domain' ),
			]
		);

		$this->add_control(
			'gallery_list',
			[
				'label' => __( 'Repeater List', 'zuzu-hp' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ image_title }}}',
			]
        );
        
       
        
        
        $this->end_controls_section();
        $this->start_controls_section(
            'section_width_nd_height',
            [
                'label' => __('Width & Height', 'zuzu-hp'),
            ]
        );


        $this->add_responsive_control(
            'post_grid',
            [
                'label' => __('Post grid', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => array(
                    '12' => '1 Column',
                    '6' => '2 Column',
                    '4' => '3 Column',
                    '3' => '4 Column',
                ),
                'default'            => 3,
                'condition' => [
                    'layout_type!' => 'slider'
                ]
            ]
        );

        $this->add_responsive_control(
            'column_verti_gap',
            [
                'label' => __('Column Vertical Gap', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'devices' => ['desktop', 'tablet', 'mobile'],
                'size_units' => ['px', '%'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'desktop_default' => [
                    'size' => 15,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}}  .zuzu-portfolio-item-wrap' => 'padding: 0 {{SIZE}}{{UNIT}} 0;',
                ]
            ]
        );

        $this->add_responsive_control(
            'column_hori_gap',
            [
                'label' => __('Column Horizontal Gap', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'devices' => ['desktop', 'tablet', 'mobile'],
                'size_units' => ['px', '%'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                ],
                'desktop_default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}}  .zuzu-portfolio-item-wrap' => 'padding-bottom: {{SIZE}}{{UNIT}} ;',
                ],
                'condition' => [
                    'layout_type!' => 'slider'
                ]
            ]
        );
        $this->add_control(
            'use_custom_height',
            [
                'label' => __('Use custom height?', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'zuzu-hp'),
                'label_off' => __('No', 'zuzu-hp'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );
        $this->add_responsive_control(
            'normal_image_height',
            [
                'label' => __('Normal Image Height', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'devices' => ['desktop', 'tablet', 'mobile'],
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}}  .zuzu-portfolio-item img' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'use_custom_height' => 'yes'
                ],
            ]
        );

        $this->end_controls_section();
              
    //Slider Setting
    $this->start_controls_section('slider_settings',
    [
            'label' => __('Slider Settings', 'zuzu-hp'),
            'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            'condition' => [
                'layout_type' => 'slider'
            ]
            ]
        );

        $this->add_responsive_control(
            'per_coulmn',
            [
                'label' => __( 'Slider Items', 'zuzu-hp' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default'            => 3,
                'tablet_default'     => 2,
                'mobile_default'     => 1,
                'options'            => [
                    '1' => '1',
                    '2' => '2',
                    '3' => '3',
                    '4' => '4',
                    '5' => '5',
                ],
                'frontend_available' => true,
            ]
        );
        $this->add_control(
            'arrows',
            [
                'label' => __( 'Show arrows?', 'zuzu-hp' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'zuzu-hp' ),
                'label_off' => __( 'Hide', 'zuzu-hp' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'dots',
            [
                'label' => __( 'Show Dots?', 'zuzu-hp' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'zuzu-hp' ),
                'label_off' => __( 'Hide', 'zuzu-hp' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'mousedrag',
            [
                'label' => __( 'Show MouseDrag', 'zuzu-hp' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'zuzu-hp' ),
                'label_off' => __( 'Hide', 'zuzu-hp' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'autoplay',
            [
                'label' => __( 'Auto Play?', 'zuzu-hp' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'zuzu-hp' ),
                'label_off' => __( 'Hide', 'zuzu-hp' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'loop',
            [
                'label' => __( 'Infinite Loop', 'zuzu-hp' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'zuzu-hp' ),
                'label_off' => __( 'Hide', 'zuzu-hp' ),
                'return_value' => 'yes',
                'default' => 'true',
            ]
        );
        $this->add_control(
            'autoplaytimeout',
            [
                'label' => __( 'Autoplay Timeout', 'zuzu-hp' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'label_block' => true,
                'default' => '5000',
                'options' => [
                    '1000'  => __( '1 Second', 'zuzu-hp' ),
                    '2000'  => __( '2 Second', 'zuzu-hp' ),
                    '3000'  => __( '3 Second', 'zuzu-hp' ),
                    '4000'  => __( '4 Second', 'zuzu-hp' ),
                    '5000'  => __( '5 Second', 'zuzu-hp' ),
                    '6000'  => __( '6 Second', 'zuzu-hp' ),
                    '7000'  => __( '7 Second', 'zuzu-hp' ),
                    '8000'  => __( '8 Second', 'zuzu-hp' ),
                    '9000'  => __( '9 Second', 'zuzu-hp' ),
                    '10000' => __( '10 Second', 'zuzu-hp' ),
                    '11000' => __( '11 Second', 'zuzu-hp' ),
                    '12000' => __( '12 Second', 'zuzu-hp' ),
                    '13000' => __( '13 Second', 'zuzu-hp' ),
                    '14000' => __( '14 Second', 'zuzu-hp' ),
                    '15000' => __( '15 Second', 'zuzu-hp' ),
                ],
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]	
        );

        $this->add_control(
            'arrow_prev_icon',
            [
                'label' => __( 'Previous Icon', 'zuzu' ),
                'label_block' => false,
                'type' => \Elementor\Controls_Manager::ICONS,
                'skin' => 'inline',
                'default' => [
                    'value' => 'fas fa-chevron-left',
                    'library' => 'fa-solid',
                ],
            ]
        );

        $this->add_control(
            'arrow_next_icon',
            [
                'label' => __( 'Next Icon', 'zuzu' ),
                'label_block' => false,
                'type' => \Elementor\Controls_Manager::ICONS,
                'skin' => 'inline',
                'default' => [
                    'value' => 'fas fa-chevron-right',
                    'library' => 'fa-solid',
                ],
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_image',
            [
                'label' => __('Image', 'zuzu-hp'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->start_controls_tabs(
            'image_hover_tabs'
        );
        $this->start_controls_tab(
            'image_normal_tab',
            [
                'label' => __('Normal', 'zuzu-hp'),
            ]
        );
        $this->add_responsive_control(
            'image_radius',
            [
                'label' => __('Image Radius', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    ' {{WRAPPER}} .zuzu-portfolio-item img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'image_shadow',
                'label' => __('Button Shadow', 'zuzu-hp'),
                'selector' => '{{WRAPPER}} .zuzu-portfolio-item img',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'image_border',
                'label' => __('Border', 'zuzu-hp'),
                'selector' => '{{WRAPPER}} .zuzu-portfolio-item img',
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab(
            'image_hover_tab',
            [
                'label' => __('Hover', 'zuzu-hp'),
            ]
        );
        $this->add_responsive_control(
            'image_hover_radius',
            [
                'label' => __('Box Image Radius', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    ' {{WRAPPER}} .zuzu-portfolio-item:hover img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'image_hover_shadow',
                'label' => __('Button Shadow', 'zuzu-hp'),
                'selector' => '{{WRAPPER}} .zuzu-portfolio-item:hover img',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'image_hover_border',
                'label' => __('Border', 'zuzu-hp'),
                'selector' => '{{WRAPPER}} .zuzu-portfolio-item:hover img',
            ]
        );
        $this->add_control(
            'enable_hover_rotate',
            [
                'label' => __('Rotate animation on hover?', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'zuzu-hp'),
                'label_off' => __('No', 'zuzu-hp'),
                'return_value' => 'zuzu-hover-rotate',
                'default' => 'no',
            ]
        );
        
        $this->add_control(
            'image_hover_animation',
            [
                'label' => __('Hover Animation', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::HOVER_ANIMATION,
                // 'prefix_class' => 'elementor-animation-',
                'condition' => [
                    'enable_hover_rotate!' => 'zuzu-hover-rotate'
                ],
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

        $this->start_controls_section(
            'section_title_style',
            [
                'label' => __('Title', 'zuzu-hp'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->start_controls_tabs(
            'title_style_tabs'
        );
        $this->start_controls_tab(
            'title_style_normal_tab',
            [
                'label' => __('Normal', 'zuzu-hp'),
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'label' => __('Title Typography', 'zuzu-hp'),
                'name' => 'title_typo',
                'selector' => '{{WRAPPER}} .zuzu-portfolio-title',
            ]
        );
        $this->add_control(
            'title_color',
            [
                'label' => __('Title Color', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .zuzu-portfolio-title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'title_align',
            [
                'label' => __('Align', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'flex-start' => __('Left', 'zuzu-hp'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => __('top', 'zuzu-hp'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'flex-end' => [
                        'title' => __('Right', 'zuzu-hp'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .zuzu-portfolio-content h3' => 'justify-content: {{VALUE}};',
                ],
                'toggle' => true,
            ]
        );
       
        $this->end_controls_tab();
        $this->start_controls_tab(
            'title_style_hover_tab',
            [
                'label' => __('Hover', 'zuzu-hp'),
            ]
        );
        $this->add_control(
            'title_color_hover',
            [
                'label' => __('Title Color', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .zuzu-portfolio-title:hover' => 'color: {{VALUE}};',
                ],
            ]
        );
       
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

        $this->start_controls_section(
            'section_content_style',
            [
                'label' => __('Content Box', 'zuzu-hp'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        
  
        $this->add_control(
            'content_bg_color',
            [
                'label' => __('Content Background Color', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .zuzu-portfolio-content' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'content_gap',
            [
                'label' => __('Content gap', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 400,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}}  .zuzu-portfolio-content.content-postion-on-image' => 'left:{{SIZE}}{{UNIT}};right:{{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'content_y_position',
            [
                'label' => __('Content Y Position', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}}  .zuzu-portfolio-content.content-postion-on-image' => 'bottom:{{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __('Content Padding', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .zuzu-portfolio-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'content_radius',
            [
                'label' => __('Content Box Radius', 'zuzu-hp'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .zuzu-portfolio-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();


   /*
   * 
    Dots
   */
    $this->start_controls_section(
        'dots_navigation',
        [
            'label' => __('Navigation - Dots', 'zuzu-hp'),
            'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            'condition' => [
                'layout_type' => 'slider',
            ]
        ]
    );

    $this->add_control(
        'dots_color',
        [
            'label' => __('Color', 'zuzu-hp'),
            'type' => \Elementor\Controls_Manager::COLOR,
            'default' => '',
            'selectors' => [
                '{{WRAPPER}} .zuzu-pf-gallery-slider-dots' => 'background-color: {{VALUE}};',
            ],
        ]
    );

    $this->add_control(
        'dots_color_active',
        [
            'label' => __('Active Color', 'zuzu-hp'),
            'type' => \Elementor\Controls_Manager::COLOR,
            'default' => '',
            'selectors' => [
                '{{WRAPPER}} .zuzu-pf-gallery-slider-dots li.slick-active button' => 'background-color: {{VALUE}};',
            ],
        ]
    );


 

  
    $this->end_controls_section();

   /*
   * 
    Arrows
   */
    $this->start_controls_section(
        'arrows_navigation',
        [
            'label' => __('Navigation - Arrow', 'zuzu-hp'),
            'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            'condition' => [
                'layout_type' => 'slider',
            ]
        ]
    );

    $this->start_controls_tabs('_tabs_arrow');

    $this->start_controls_tab(
        '_tab_arrow_normal',
        [
            'label' => __('Normal', 'zuzu-hp'),
        ]
    );

    $this->add_control(
        'arrow_color',
        [
            'label' => __('Color', 'zuzu-hp'),
            'type' => \Elementor\Controls_Manager::COLOR,
            'default' => '',
            'selectors' => [
                '{{WRAPPER}} .zuzu-pf-gallery-slider .slick-arrow i' => 'color: {{VALUE}}; border-color: {{VALUE}};',
                '{{WRAPPER}} .zuzu-pf-gallery-slider .slick-arrow svg path' => 'stroke: {{VALUE}};',
            ],
        ]
    );
    
    $this->add_control(
        'arrow_color_fill',
        [
            'label' => __('Line Color', 'zuzu-hp'),
            'type' => \Elementor\Controls_Manager::COLOR,
            'default' => '',
            'selectors' => [
                '{{WRAPPER}} .zuzu-pf-gallery-slider .slick-arrow i:vefore' => 'color: {{VALUE}};',
                '{{WRAPPER}} .zuzu-pf-gallery-slider .slick-arrow svg path' => 'fill: {{VALUE}};',
            ],
        ]
    );

    $this->add_control(
        'arrow_bg_color',
        [
            'label' => __('Background Color', 'zuzu-hp'),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                 '{{WRAPPER}} .zuzu-pf-gallery-slider button.slick-arrow' => 'background-color: {{VALUE}} !important;',
            ],
        ]
    );
    $this->add_group_control(
        \Elementor\Group_Control_Border::get_type(),
        [
            'name' => 'arrow_border',
            'label' => __('Border', 'zuzu-hp'),
            'selector' => '{{WRAPPER}} .zuzu-pf-gallery-slider button.slick-arrow',
        ]
    );
    $this->add_responsive_control(
        'arrow_icon_radius',
        [
            'label' => __('Arrow Radius', 'zuzu-hp'),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => ['px', 'em', '%'],
            'selectors' => [
                ' {{WRAPPER}} .zuzu-pf-gallery-slider button.slick-arrow' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]
    );
    $this->add_group_control(
        \Elementor\Group_Control_Box_Shadow::get_type(),
        [
            'name' => 'arrow_shadow',
            'label' => __('Shadow', 'fd-addons'),
            'selector' => '{{WRAPPER}} .zuzu-pf-gallery-slider button.slick-arrow',
        ]
    );

    $this->end_controls_tab();

    $this->start_controls_tab(
        '_tab_arrow_hover',
        [
            'label' => __('Hover', 'zuzu-hp'),
        ]
    );

    $this->add_control(
        'arrow_hover_color',
        [
            'label' => __('Color', 'zuzu-hp'),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                 '{{WRAPPER}} .zuzu-pf-gallery-slider .slick-arrow:hover i:vefore' => 'color: {{VALUE}};',
                 '{{WRAPPER}} .zuzu-pf-gallery-slider .slick-arrow:hover svg path' => 'stroke: {{VALUE}};',
            ],
        ]
    );

    $this->add_control(
        'arrow_hover_fill_color',
        [
            'label' => __('Line Color', 'zuzu-hp'),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                 '{{WRAPPER}} .zuzu-pf-gallery-slider .slick-arrow:hover i:vefore' => 'color: {{VALUE}};',
                 '{{WRAPPER}} .zuzu-pf-gallery-slider .slick-arrow:hover svg path' => 'fill: {{VALUE}};',
            ],
        ]
    );

    $this->add_control(
        'arrow_bg_hover_color',
        [
            'label' => __('Background Color Hover', 'zuzu-hp'),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                 '{{WRAPPER}} .zuzu-pf-gallery-slider .zuzu-slick-next:hover, .zuzu-pf-gallery-slider .zuzu-slick-prev:hover' => 'background-color: {{VALUE}}  !important;',
            ],
        ]
    );

    $this->add_group_control(
        \Elementor\Group_Control_Border::get_type(),
        [
            'name' => 'arrow_hover_border',
            'label' => __('Border', 'zuzu-hp'),
            'selector' => '{{WRAPPER}} .zuzu-pf-gallery-slider button.slick-arrow:hover',
        ]
    );
    $this->add_responsive_control(
        'arrow_hover_icon_radius',
        [
            'label' => __('Arrow Radius', 'zuzu-hp'),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => ['px', 'em', '%'],
            'selectors' => [
                ' {{WRAPPER}} .zuzu-pf-gallery-slider button.slick-arrow:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]
    );
    $this->add_group_control(
        \Elementor\Group_Control_Box_Shadow::get_type(),
        [
            'name' => 'arrow_hover_shadow',
            'label' => __('Shadow Hover', 'fd-addons'),
            'selector' => '{{WRAPPER}} .zuzu-pf-gallery-slider .zuzu-slick-next:hover, {{WRAPPER}} .zuzu-pf-gallery-slider .zuzu-slick-prev:hover',
        ]
    );
    $this->end_controls_tab();
    $this->end_controls_tabs();

    $this->add_control(
        'hrthere',
        [
            'type' => \Elementor\Controls_Manager::DIVIDER,
        ]
    ); 

    $this->add_control(
        'arrow_position_toggle',
        [
            'label' => __('Position', 'zuzu-hp'),
            'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
            'label_off' => __('None', 'zuzu-hp'),
            'label_on' => __('Custom', 'zuzu-hp'),
            'return_value' => 'yes',
        ]
    );
    $this->start_popover();

    /* 
    Arrow Position
    */
    $this->add_responsive_control(
        'arrow_position_y',
        [
            'label' => __('Vertical', 'zuzu-hp'),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'size_units' => ['%','px'],
            'condition' => [
                'arrow_position_toggle' => 'yes'
            ],
            'range' => [
                'px' => [
                    'min' => -1000,
                    'max' => 1000,
                ],
                '%' => [
                    'min' => -100,
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .zuzu-pf-gallery-slider button.slick-arrow' => 'bottom: {{SIZE}}{{UNIT}} !important;',
            ],
        ]
    );

    $this->add_responsive_control(
        'arrow_prev_position',
        [
            'label' => __('Prev icon Position', 'zuzu-hp'),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'size_units' => ['px', '%'],
            'condition' => [
                'arrow_position_toggle' => 'yes'
            ],
            'range' => [
                'px' => [
                    'min' => -2000,
                    'max' => 2000,
                ],
                '%' => [
                    'min' => -100,
                    'max' => 100,
                ],
            ],
            'selectors' => [
                'body:not(.rtl) {{WRAPPER}} .zuzu-pf-gallery-slider .slick-arrow.zuzu-slick-prev' => 'left: {{SIZE}}{{UNIT}};',
            ],
        ]
    );
    $this->add_responsive_control(
        'arrow_nextv_position',
        [
            'label' => __('Next icon Position', 'zuzu-hp'),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'size_units' => ['px', '%'],
            'condition' => [
                'arrow_position_toggle' => 'yes'
            ],
            'range' => [
                'px' => [
                    'min' => -2000,
                    'max' => 2000,
                ],
                '%' => [
                    'min' => -100,
                    'max' => 100,
                ],
            ],
            'selectors' => [
                'body:not(.rtl) {{WRAPPER}} .zuzu-pf-gallery-slider .slick-arrow.zuzu-slick-next' => 'right: {{SIZE}}{{UNIT}}; left:auto;',
            ],
        ]
    );


    // $this->add_responsive_control(
    //     'arrow_position_right_gap',
    //     [
    //         'label' => __('Prev Aarrow Gap', 'zuzu-hp'),
    //         'type' => \Elementor\Controls_Manager::SLIDER,
    //         'size_units' => ['px'],
    //         'condition' => [
    //             'arrow_position_toggle' => 'yes'
    //         ],
    //         'range' => [
    //             'px' => [
    //                 'min' => -1000,
    //                 'max' => 2000,
    //             ],
    //         ],
    //         'selectors' => [
    //             'body:not(.rtl) {{WRAPPER}} .zuzu-pf-gallery-slider .slick-arrow.zuzu-slick-next' => 'right: {{SIZE}}{{UNIT}};',
    //             'body.rtl {{WRAPPER}} .zuzu-pf-gallery-slider .slick-arrow  button.zuzu-slick-prev' => 'left: {{SIZE}}{{UNIT}};',
    //         ],
    //     ]
    // );
    $this->end_popover();

    $this->add_responsive_control(
        'arrow_icon_size',
        [
            'label' => __('Icon Size', 'zuzu-hp'),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'size_units' => ['px'],
            'range' => [
                'px' => [
                    'min' => 10,
                    'max' => 150,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}}  .zuzu-pf-gallery-slider .slick-arrow i' => 'font-size: {{SIZE}}{{UNIT}}',
                '{{WRAPPER}}  .zuzu-pf-gallery-slider .slick-arrow svg' => 'width: {{SIZE}}{{UNIT}}',
            ],
        ]
    );
    
    $this->add_responsive_control(
        'arrow_size_box',
        [
            'label' => __('Size', 'zuzu-hp'),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'size_units' => ['px'],
            'range' => [
                'px' => [
                    'min' => 20,
                    'max' => 150,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .zuzu-pf-gallery-slider button.slick-arrow' => 'height: {{SIZE}}{{UNIT}}; width: {{SIZE}}{{UNIT}};',
            ],
        ]
    );

    
    $this->end_controls_section();
    }

    protected function get_render_icon($icon){
        ob_start();
        \Elementor\Icons_Manager::render_icon($icon, ['aria-hidden' => 'true']);
        return ob_get_clean();
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings();
        $paged = get_query_var('paged') ? get_query_var('paged') : 1;
        $portfolio_data = [];
        $portfolio_data['settings'] = $this->get_settings();
        $portfolio_data = json_encode($portfolio_data);
        $post_grid_desktop = $settings['post_grid'];
        $post_grid_tablet  = $settings['post_grid_tablet'];
        $post_grid_mobile  = $settings['post_grid_mobile'];
        //this code slider option
        $slider_extraSetting = array(
            
            'next_icon' => $this->get_render_icon($settings['arrow_next_icon']),
            'prev_icon' => $this->get_render_icon($settings['arrow_prev_icon']),
            
            'loop' => (!empty($settings['loop']) && 'yes' === $settings['loop']) ? true : false,
            'dots' => (!empty($settings['dots']) && 'yes' === $settings['dots']) ? true : false,
            'autoplay' => (!empty($settings['autoplay']) && 'yes' === $settings['autoplay']) ? true : false,
            'nav' => (!empty($settings['arrows']) && 'yes' === $settings['arrows']) ? true : false,
            'mousedrag' => (!empty($settings['mousedrag']) && 'yes' === $settings['mousedrag']) ? true : false,
            'autoplaytimeout' => !empty($settings['autoplaytimeout']) ? $settings['autoplaytimeout'] : '5000',
            
            //this a responsive layout
            'per_coulmn' =>        (!empty($settings['per_coulmn'])) ? $settings['per_coulmn'] : 3,
            'per_coulmn_tablet' => (!empty($settings['per_coulmn_tablet'])) ? $settings['per_coulmn_tablet'] : 2,
            'per_coulmn_mobile' => (!empty($settings['per_coulmn_mobile'])) ? $settings['per_coulmn_mobile'] : 1
        );
        
        $jasondecode = wp_json_encode($slider_extraSetting);
        if('slider' == $settings['layout_type']){
            $this->add_render_attribute('pf_gallery_slide', 'data-settings', $jasondecode);
        }


?>
        <?php if('slider' == $settings['layout_type']):  ?>
            <div class="zuzu-pf-gallery-slider" <?php echo $this->get_render_attribute_string('pf_gallery_slide'); ?>>
                <?php 
                    $i = 0;
                    foreach (  $settings['gallery_list'] as $item ) : 
                        $image_size = ( $item['image_size']['width'] || $item['image_size']['height'] ) ? [$item['image_size']['width'] , $item['image_size']['height']] : 'full';
                    ?>
                        <div class="zuzu-portfolio-item" <?php //echo  $this->get_render_attribute_string( 'zuzu-gallery-lightbox-'.$i ) ; ?>>
                            <a href="<?php echo wp_get_attachment_image_url( $item['image']['id'], 'full'  ) ?>" class="zuzu-portfolio-image d-block <?php echo esc_attr('elementor-animation-'.$settings['image_hover_animation']) ?>">
                                <?php echo wp_get_attachment_image( $item['image']['id'], $image_size  ); ?>
                            </a>
                            <?php if(!empty($item['image_title'])):?>
                            <a href="<?php echo wp_get_attachment_image_url( $item['image']['id'], 'full'  ) ?>" class="zuzu-portfolio-content content-postion-on-image">
                                <h3 class="zuzu-portfolio-title">
                                    <?php echo esc_html( $item['image_title'] ) ?>
                                </h3>
                            </a>
                            <?php endif; ?>
                        </div>
                        <?php endforeach; ?>
                </div>

            <?php else: ?>

            <div class="row justify-content-center zuzu-pf-gallery-wrap layout-mode-<?php echo esc_attr($settings['layout_type'] . ' ' . $settings['enable_hover_rotate']) ?>">
                <?php 
                $i = 0;
                foreach (  $settings['gallery_list'] as $item ) : 
                    $i++;
                    $unique_id = rand(100, 10000);
                    $image_size = ( $item['image_size']['width'] || $item['image_size']['height'] ) ? [$item['image_size']['width'] , $item['image_size']['height']] : 'full';
                    if(!empty($item['image_grid'])){
                        $image_grid_desktop = $item['image_grid'];
                        $image_grid_tablet  = $item['image_grid_tablet'];
                        $image_grid_mobile  = $item['image_grid_mobile'];
                        $grid = sprintf('col-lg-%s col-md-%s col-%s', esc_attr($image_grid_desktop), esc_attr($image_grid_tablet), esc_attr($image_grid_mobile));   
                    }else{
                        $grid = sprintf('col-lg-%s col-md-%s col-%s', esc_attr($post_grid_desktop), esc_attr($post_grid_tablet), esc_attr($post_grid_mobile));    
                    }
                ?>
                <div class="zuzu-portfolio-item-wrap <?php echo esc_attr( $grid ) ?>"  >

                    <div class="zuzu-portfolio-item" <?php echo  $this->get_render_attribute_string( 'zuzu-gallery-lightbox-'.$i ) ; ?>>
                        <a href="<?php echo wp_get_attachment_image_url( $item['image']['id'], 'full'  ) ?>" class="zuzu-portfolio-image d-block <?php echo esc_attr('elementor-animation-'.$settings['image_hover_animation']) ?>">
                            <?php echo wp_get_attachment_image( $item['image']['id'], $image_size  ); ?>
                        </a>
                        <?php if(!empty($item['image_title'])):?>
                        <a href="<?php echo wp_get_attachment_image_url( $item['image']['id'], 'full'  ) ?>" class="zuzu-portfolio-content content-postion-on-image">
                            <h3 class="zuzu-portfolio-title">
                                <?php echo esc_html( $item['image_title'] ) ?>
                            </h3>
                        </a>
                        <?php endif; ?>
                    </div>
                </div>
                <?php endforeach; ?>
            </div>
            
         <?php endif;?>
<?php

    }
}

$widgets_manager->register_widget_type(new \Zuzu_Portfolio_Gallery());